@@ -1,6 +1,6 @@
 package Type::Constraint::Role::CanType;
 {
-  $Type::Constraint::Role::CanType::VERSION = '0.01'; # TRIAL
+  $Type::Constraint::Role::CanType::VERSION = '0.02'; # TRIAL
 }
 
 use strict;
@@ -52,3 +52,39 @@ override BUILDARGS => sub {
 };
 
 1;
+
+# ABSTRACT: Provides a common implementation for Type::Constraint::AnyCan and Type::Constraint::ObjectCan
+
+
+
+=pod
+
+=head1 NAME
+
+Type::Constraint::Role::CanType - Provides a common implementation for Type::Constraint::AnyCan and Type::Constraint::ObjectCan
+
+=head1 VERSION
+
+version 0.02
+
+=head1 DESCRIPTION
+
+See L<Type::Constraint::AnyCan> and L<Type::Constraint::ObjectCan> for details.
+
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
+
+
+__END__
+
